# lins-unous #

Pacote para ser utilizado na integração Unous.

## Variaveis de Ambiente necessarias

> ### GRAN_TYPE 
>> Parametro necessário para token da UNOUS

> ### USERNAME     
>> Parametro necessário para token da UNOUS
 
> ### PASSWORD     
>> Parametro necessário para token da UNOUS 

> ### CLIENT_ID    
>> Parametro necessário para token da UNOUS

> ### URL_TOKEN   
>> URL para buscar token

> ### URL_METRICS         
>> URL UNOUS Metrics

> ### URL_CONTENT
>> UREL UNOUS Content

## Integracoes

> ### Produtos
>> Basta instanciar a classe ApiUnous e chamar o metodo integrar_produtos passando a lista de produtos

> ### Produtos Tamanhos 
>> Basta instanciar a classe ApiUnous e chamar o metodo integrar_produtos_tamanhos passando a lista de produtos tamanhos

> ### Integrar fornecedores
>> Basta instanciar a classe ApiUnous e chamar o metodo integrar_fornecedores passando a lista de fornecedores

> ### Integrar pedidos
>> Basta instanciar a classe ApiUnous e chamar o metodo integrar_pedidos passando a lista de pedidos

> ### Integrar lojas
>> Basta instanciar a classe ApiUnous e chamar o metodo integrar_lojas passando a lista de lojas

> ### Integrar lojas informacoes
>> Basta instanciar a classe ApiUnous e chamar o metodo integrar_lojas_info passando a lista de lojas informações

> ### integrar metricas
>> Basta instanciar a classe ApiUnous e chamar o metodo integrar metricas passando a lista de metricas